//
//  LottoData.m
//
// This is the MODEL part of the MVC model
//
// It handles the data set of the Lotto applications
//

#import "LottoData.h"
#import "Defines.h"


@implementation LottoData


// Convenience class methods that return an initialized and autoreleased object
+ (LottoData *)lottoData {
    return [[[self alloc] init] autorelease];
}

+ (LottoData *)lottoDataWithCount:(int)count {
    return [[[self alloc] initWithCount:count] autorelease];
}

// Override init, see Hillegass: Cocoa Programming, p.67 (1st Ed)
- (id)init
{
    return [self initWithCount:35];
}

// The designated initializer that takes the parameter count
- (id)initWithCount:(int)count
{
    if ( self = [super init] ) {
        int i;
        NSNumber *number;
        
        // seed the random number generator
        srandom(time(NULL));
        
        // create an array to hold the numbers
        numbers = [[NSMutableArray alloc] init];

        // fill it with 'count' sequental numbers, starting at one
        for ( i = 1; i < (count + 1); i++ ) {
			number = [NSNumber numberWithInt:i]; // creates an autoreleased object
            [numbers addObject:number];
        }
	}
    return self;
}

// Shuffle all the numbers in the array
- (void)randomize {
    int i, n = [numbers count];

    for ( i = 0; i < n; i++ ) {
        [numbers exchangeObjectAtIndex:i withObjectAtIndex:(random() % n)];
    }
}

// Accessor methods
- (NSMutableArray *)numbers {
    return numbers;
}

// These methods are required by LottofleX
- (void)setNumbers:(NSMutableArray *)array {
    [array retain];
    [numbers release];
    numbers = array;
}

- (void)dealloc
{
    [self setNumbers:nil]; // numbers is released in set method
    [super dealloc];
}

#pragma mark -
#pragma mark Debugging

// NSObject method that can be used for debugging with 'po' command in GDB
// This method is used when NSLog() describes the object %@
// It could also be used in a GUI status display; Cocoa Dev Central: All Purpose App
- (NSString *)description
{
    return [NSString stringWithFormat:@"Array with %d numbers: %@", [numbers count], numbers];
}

@end
