//
//  TitleViewController.m
//  LottoTouch
//
//  Created by Bertils mini on 2008-06-06.
//  Copyright 2008-2009 Sork Software. All rights reserved.
//

#import "TitleViewController.h"
#import "PickerViewController.h"
#import "Defines.h"


@interface TitleViewController (Private)
- (void)saveAction:(id)sender;
@end


@implementation TitleViewController

@synthesize gameTitle, titleField, newGame;


- (id)init
{
	if (self = [super init])
	{
		// This will appear as the title in the navigation bar
		self.title = NSLocalizedString(@"TitleViewTitle", @"");
	}
	
	return self;
}

- (void)dealloc
{
	[titleField release];
	[super dealloc];
}


- (void)loadView
{
	// Setup the content view
	UIView *contentView = [[UIView alloc] initWithFrame:[[UIScreen mainScreen] applicationFrame]];
	
	// Use the table view background color
	contentView.backgroundColor = [UIColor groupTableViewBackgroundColor];
	
	// Add it as the parent/content view to this UIViewController
	self.view = contentView;
	[contentView release];
	
	// Add a Save bar button in the nav bar's right view to save new titles
	UIBarButtonItem *saveButton = [[UIBarButtonItem alloc]
									initWithTitle:NSLocalizedString(@"SaveButtonTitle", @"")
									style:UIBarButtonItemStyleDone
									target:self
									action:@selector(saveAction:)];
	self.navigationItem.rightBarButtonItem = saveButton;
	[saveButton release];
	
	// Create a text field to type into
    CGFloat textFieldWidth = self.view.bounds.size.width - (kRightMargin * 2.0);
	CGRect textFieldFrame = CGRectMake(kLeftMargin,
									   kTweenMargin,
									   textFieldWidth,
									   kTextFieldHeight);
    UITextField *aTextField = [[UITextField alloc] initWithFrame:textFieldFrame];
    aTextField.borderStyle = UITextBorderStyleRoundedRect;
    aTextField.font = [UIFont systemFontOfSize:kTextFieldFontSize];
    aTextField.contentVerticalAlignment = UIControlContentVerticalAlignmentCenter;
    aTextField.placeholder = NSLocalizedString(@"GameTitle", @"Title View Text Field Placeholder");
    aTextField.keyboardType = UIKeyboardTypeDefault;
	aTextField.returnKeyType = UIReturnKeyDone;
	aTextField.clearButtonMode = UITextFieldViewModeWhileEditing;	// has a clear 'x' button to the right
    aTextField.delegate = self;
	[aTextField becomeFirstResponder];
    self.titleField = aTextField;
	[aTextField release];
	[self.view addSubview:self.titleField];
}

// Asked when the delegate should process the Return/Done button
- (BOOL)textFieldShouldReturn:(UITextField *)theTextField {
	if (theTextField == self.titleField) {
		// Remove the keyboard and save the new/modified text
		[self.titleField resignFirstResponder];
		[self saveAction:self];
	}
	return YES;
}

#pragma mark -
#pragma mark Action methods

// The actual saving is done in the LottoViewController although initiated by the Picker View
- (void)saveAction:(id)sender
{
	// Make sure the picker view will receive a valid title string
	if (self.titleField.text == @"")
		self.gameTitle = NSLocalizedString(@"NewTitle", @"");
	else
		self.gameTitle = self.titleField.text;

	NSDictionary *presetsChanged = [NSDictionary dictionaryWithObject:@"Title" forKey:@"Change"];
	
	[notificationCenter postNotificationName:SSLottoTouchPresetsChangedNotification
									  object:self userInfo:presetsChanged];
	
	// Return to the PickerViewController
	[self.navigationController popViewControllerAnimated:YES];
}

#pragma mark -
#pragma mark UIViewController methods

- (void)viewWillAppear:(BOOL)animated
{
	if (self.newGame)
		// Will reveal placeholder instead of a title string
		self.titleField.text = @"";
	else
		self.titleField.text = self.gameTitle;
	
	// Enable editing in the text field and display the keyboard
	[self.titleField becomeFirstResponder];
}

- (void)viewWillDisappear:(BOOL)animated {
    // Hide the keyboard
    [self.titleField resignFirstResponder];
}

@end
